from griptape.utils.deprecation import DeprecationModuleWrapper
import sys

from .prompt import BasePromptDriver
from .prompt.openai import OpenAiChatPromptDriver
from .prompt.openai import AzureOpenAiChatPromptDriver
from .prompt.cohere import CoherePromptDriver
from .prompt.huggingface_pipeline import HuggingFacePipelinePromptDriver
from .prompt.huggingface_hub import HuggingFaceHubPromptDriver
from .prompt.anthropic import AnthropicPromptDriver
from .prompt.amazon_sagemaker_jumpstart import AmazonSageMakerJumpstartPromptDriver
from .prompt.amazon_bedrock import AmazonBedrockPromptDriver
from .prompt.google import GooglePromptDriver
from .prompt.dummy import DummyPromptDriver
from .prompt.ollama import OllamaPromptDriver
from .prompt.grok import GrokPromptDriver
from .prompt.griptape_cloud import GriptapeCloudPromptDriver

from .memory.conversation import BaseConversationMemoryDriver
from .memory.conversation.local import LocalConversationMemoryDriver
from .memory.conversation.amazon_dynamodb import AmazonDynamoDbConversationMemoryDriver
from .memory.conversation.redis import RedisConversationMemoryDriver
from .memory.conversation.griptape_cloud import GriptapeCloudConversationMemoryDriver

from .embedding import BaseEmbeddingDriver
from .embedding.openai import OpenAiEmbeddingDriver
from .embedding.openai import AzureOpenAiEmbeddingDriver
from .embedding.amazon_sagemaker_jumpstart import AmazonSageMakerJumpstartEmbeddingDriver
from .embedding.amazon_bedrock import AmazonBedrockTitanEmbeddingDriver, AmazonBedrockCohereEmbeddingDriver
from .embedding.voyageai import VoyageAiEmbeddingDriver
from .embedding.huggingface_hub import HuggingFaceHubEmbeddingDriver
from .embedding.google import GoogleEmbeddingDriver
from .embedding.dummy import DummyEmbeddingDriver
from .embedding.cohere import CohereEmbeddingDriver
from .embedding.ollama import OllamaEmbeddingDriver

from .vector import BaseVectorStoreDriver
from .vector.local import LocalVectorStoreDriver
from .vector.pinecone import PineconeVectorStoreDriver
from .vector.marqo import MarqoVectorStoreDriver
from .vector.mongodb_atlas import MongoDbAtlasVectorStoreDriver
from .vector.redis import RedisVectorStoreDriver
from .vector.opensearch import OpenSearchVectorStoreDriver
from .vector.amazon_opensearch import AmazonOpenSearchVectorStoreDriver
from .vector.pgvector import PgVectorVectorStoreDriver
from .vector.azure_mongodb import AzureMongoDbVectorStoreDriver
from .vector.dummy import DummyVectorStoreDriver
from .vector.qdrant import QdrantVectorStoreDriver
from .vector.astradb import AstraDbVectorStoreDriver
from .vector.griptape_cloud import GriptapeCloudVectorStoreDriver

from .sql import BaseSqlDriver
from .sql.sql_driver import SqlDriver
from .sql.amazon_redshift import AmazonRedshiftSqlDriver
from .sql.snowflake import SnowflakeSqlDriver

from .image_generation_model import BaseImageGenerationModelDriver
from .image_generation_model.bedrock_stable_diffusion import BedrockStableDiffusionImageGenerationModelDriver
from .image_generation_model.bedrock_titan import BedrockTitanImageGenerationModelDriver

from .image_generation_pipeline import BaseDiffusionImageGenerationPipelineDriver
from .image_generation_pipeline.stable_diffusion_3 import StableDiffusion3ImageGenerationPipelineDriver
from .image_generation_pipeline.stable_diffusion_3_img_2_img import StableDiffusion3Img2ImgImageGenerationPipelineDriver
from .image_generation_pipeline.stable_diffusion_3_controlnet import (
    StableDiffusion3ControlNetImageGenerationPipelineDriver,
)

from .image_generation import BaseImageGenerationDriver
from .image_generation import BaseMultiModelImageGenerationDriver
from .image_generation.openai import OpenAiImageGenerationDriver, AzureOpenAiImageGenerationDriver
from .image_generation.leonardo import LeonardoImageGenerationDriver
from .image_generation.amazon_bedrock import AmazonBedrockImageGenerationDriver
from .image_generation.dummy import DummyImageGenerationDriver
from .image_generation.huggingface_pipeline import HuggingFacePipelineImageGenerationDriver

from .web_scraper import BaseWebScraperDriver
from .web_scraper.trafilatura import TrafilaturaWebScraperDriver
from .web_scraper.markdownify import MarkdownifyWebScraperDriver
from .web_scraper.proxy import ProxyWebScraperDriver

from .web_search import BaseWebSearchDriver
from .web_search.google import GoogleWebSearchDriver
from .web_search.duck_duck_go import DuckDuckGoWebSearchDriver
from .web_search.exa import ExaWebSearchDriver
from .web_search.tavily import TavilyWebSearchDriver

from .event_listener import BaseEventListenerDriver
from .event_listener.amazon_sqs import AmazonSqsEventListenerDriver
from .event_listener.webhook import WebhookEventListenerDriver
from .event_listener.aws_iot_core import AwsIotCoreEventListenerDriver
from .event_listener.griptape_cloud import GriptapeCloudEventListenerDriver
from .event_listener.pusher import PusherEventListenerDriver

from .file_manager import BaseFileManagerDriver
from .file_manager.local import LocalFileManagerDriver
from .file_manager.amazon_s3 import AmazonS3FileManagerDriver
from .file_manager.griptape_cloud import GriptapeCloudFileManagerDriver

from .rerank import BaseRerankDriver
from .rerank.cohere import CohereRerankDriver
from .rerank.local import LocalRerankDriver

from .ruleset import BaseRulesetDriver
from .ruleset.local import LocalRulesetDriver
from .ruleset.griptape_cloud import GriptapeCloudRulesetDriver

from .text_to_speech import BaseTextToSpeechDriver
from .text_to_speech.dummy import DummyTextToSpeechDriver
from .text_to_speech.elevenlabs import ElevenLabsTextToSpeechDriver
from .text_to_speech.openai import OpenAiTextToSpeechDriver, AzureOpenAiTextToSpeechDriver

from .structure_run import BaseStructureRunDriver
from .structure_run.griptape_cloud import GriptapeCloudStructureRunDriver
from .structure_run.local import LocalStructureRunDriver

from .audio_transcription import BaseAudioTranscriptionDriver
from .audio_transcription.dummy import DummyAudioTranscriptionDriver
from .audio_transcription.openai import OpenAiAudioTranscriptionDriver

from .observability import BaseObservabilityDriver
from .observability.no_op import NoOpObservabilityDriver
from .observability.open_telemetry import OpenTelemetryObservabilityDriver
from .observability.griptape_cloud import GriptapeCloudObservabilityDriver
from .observability.datadog import DatadogObservabilityDriver

from .assistant import BaseAssistantDriver
from .assistant.griptape_cloud import GriptapeCloudAssistantDriver
from .assistant.openai import OpenAiAssistantDriver


__all__ = [
    "BasePromptDriver",
    "OpenAiChatPromptDriver",
    "AzureOpenAiChatPromptDriver",
    "CoherePromptDriver",
    "HuggingFacePipelinePromptDriver",
    "HuggingFaceHubPromptDriver",
    "AnthropicPromptDriver",
    "AmazonSageMakerJumpstartPromptDriver",
    "AmazonBedrockPromptDriver",
    "GooglePromptDriver",
    "DummyPromptDriver",
    "OllamaPromptDriver",
    "GrokPromptDriver",
    "GriptapeCloudPromptDriver",
    "BaseConversationMemoryDriver",
    "LocalConversationMemoryDriver",
    "AmazonDynamoDbConversationMemoryDriver",
    "RedisConversationMemoryDriver",
    "GriptapeCloudConversationMemoryDriver",
    "BaseEmbeddingDriver",
    "OpenAiEmbeddingDriver",
    "AzureOpenAiEmbeddingDriver",
    "AmazonSageMakerJumpstartEmbeddingDriver",
    "AmazonBedrockTitanEmbeddingDriver",
    "AmazonBedrockCohereEmbeddingDriver",
    "VoyageAiEmbeddingDriver",
    "HuggingFaceHubEmbeddingDriver",
    "GoogleEmbeddingDriver",
    "DummyEmbeddingDriver",
    "CohereEmbeddingDriver",
    "OllamaEmbeddingDriver",
    "BaseVectorStoreDriver",
    "LocalVectorStoreDriver",
    "PineconeVectorStoreDriver",
    "MarqoVectorStoreDriver",
    "MongoDbAtlasVectorStoreDriver",
    "AzureMongoDbVectorStoreDriver",
    "RedisVectorStoreDriver",
    "OpenSearchVectorStoreDriver",
    "AmazonOpenSearchVectorStoreDriver",
    "PgVectorVectorStoreDriver",
    "QdrantVectorStoreDriver",
    "AstraDbVectorStoreDriver",
    "DummyVectorStoreDriver",
    "GriptapeCloudVectorStoreDriver",
    "BaseSqlDriver",
    "AmazonRedshiftSqlDriver",
    "SnowflakeSqlDriver",
    "SqlDriver",
    "BaseImageGenerationModelDriver",
    "BedrockStableDiffusionImageGenerationModelDriver",
    "BedrockTitanImageGenerationModelDriver",
    "BaseDiffusionImageGenerationPipelineDriver",
    "StableDiffusion3ImageGenerationPipelineDriver",
    "StableDiffusion3Img2ImgImageGenerationPipelineDriver",
    "StableDiffusion3ControlNetImageGenerationPipelineDriver",
    "BaseImageGenerationDriver",
    "BaseMultiModelImageGenerationDriver",
    "OpenAiImageGenerationDriver",
    "LeonardoImageGenerationDriver",
    "AmazonBedrockImageGenerationDriver",
    "AzureOpenAiImageGenerationDriver",
    "DummyImageGenerationDriver",
    "HuggingFacePipelineImageGenerationDriver",
    "BaseWebScraperDriver",
    "TrafilaturaWebScraperDriver",
    "MarkdownifyWebScraperDriver",
    "ProxyWebScraperDriver",
    "BaseWebSearchDriver",
    "GoogleWebSearchDriver",
    "DuckDuckGoWebSearchDriver",
    "ExaWebSearchDriver",
    "TavilyWebSearchDriver",
    "BaseEventListenerDriver",
    "AmazonSqsEventListenerDriver",
    "WebhookEventListenerDriver",
    "AwsIotCoreEventListenerDriver",
    "GriptapeCloudEventListenerDriver",
    "PusherEventListenerDriver",
    "BaseFileManagerDriver",
    "LocalFileManagerDriver",
    "AmazonS3FileManagerDriver",
    "GriptapeCloudFileManagerDriver",
    "BaseRerankDriver",
    "CohereRerankDriver",
    "LocalRerankDriver",
    "BaseRulesetDriver",
    "LocalRulesetDriver",
    "GriptapeCloudRulesetDriver",
    "BaseTextToSpeechDriver",
    "DummyTextToSpeechDriver",
    "ElevenLabsTextToSpeechDriver",
    "OpenAiTextToSpeechDriver",
    "AzureOpenAiTextToSpeechDriver",
    "BaseStructureRunDriver",
    "GriptapeCloudStructureRunDriver",
    "LocalStructureRunDriver",
    "BaseAudioTranscriptionDriver",
    "DummyAudioTranscriptionDriver",
    "OpenAiAudioTranscriptionDriver",
    "BaseObservabilityDriver",
    "NoOpObservabilityDriver",
    "OpenTelemetryObservabilityDriver",
    "GriptapeCloudObservabilityDriver",
    "DatadogObservabilityDriver",
    "BaseAssistantDriver",
    "GriptapeCloudAssistantDriver",
    "OpenAiAssistantDriver",
]


sys.modules[__name__] = DeprecationModuleWrapper(
    sys.modules[__name__],
    deprecation_message="Importing from `griptape.drivers` is deprecated and will be removed in a future release. "
    "Please import from the provider-specific package instead.\n"
    "e.g., `from griptape.drivers import OpenAiChatPromptDriver` -> `from griptape.drivers.prompt.openai import OpenAiChatPromptDriver`",
)
